import { Component, Input, ViewChild, Renderer2, HostListener } from '@angular/core';
import { WindowRef } from '../window-ref/window-ref.service';
import { OverlayContentComponent } from './overlay-content.component';
import { centerWindowPosition } from '../utils/dom-utils';
var OverlayComponent = (function () {
    function OverlayComponent(windowRef, renderer) {
        this.windowRef = windowRef;
        this.renderer = renderer;
    }
    OverlayComponent.prototype.ngOnInit = function () {
    };
    OverlayComponent.prototype.addContent = function (options) {
        this.overlayOptions = options;
        if (!this.overlayOptions.html && this.overlayOptions.component) {
            this.overlayContent.addContent(this.overlayOptions);
        }
        this.adjustOverlayPosition();
    };
    OverlayComponent.prototype.onWinResize = function () {
        this.adjustOverlayPosition();
    };
    OverlayComponent.prototype.adjustOverlayPosition = function () {
        var _this = this;
        setTimeout(function () {
            var pos = centerWindowPosition(_this.overlayBody, _this.windowRef);
            _this.renderer.setStyle(_this.overlayBody.nativeElement, 'top', pos.top + "px");
            _this.renderer.setStyle(_this.overlayBody.nativeElement, 'left', pos.left + "px");
        }, 0);
    };
    return OverlayComponent;
}());
export { OverlayComponent };
OverlayComponent.decorators = [
    { type: Component, args: [{
                selector: 're-overlay',
                template: "\n    <div #overlayBody class=\"overlay-body\" style=\"z-index: 1050;top:300px;left: 200px;\">\n      <div *ngIf=\"overlayOptions?.html\" [innerHTML]=\"overlayOptions.html\"></div>\n      <re-overlay-content #overlayContent style=\"display: none;\"></re-overlay-content>\n    </div>\n    <re-modal-backdrop [isOpen]=\"true\" [modalOptions]=\"overlayOptions\"></re-modal-backdrop>\n  ",
                styles: ["\n    .overlay-body{position:fixed}\n  "],
            },] },
];
/** @nocollapse */
OverlayComponent.ctorParameters = function () { return [
    { type: WindowRef, },
    { type: Renderer2, },
]; };
OverlayComponent.propDecorators = {
    'overlayOptions': [{ type: Input },],
    'overlayBody': [{ type: ViewChild, args: ['overlayBody',] },],
    'overlayContent': [{ type: ViewChild, args: [OverlayContentComponent,] },],
    'onWinResize': [{ type: HostListener, args: ['window:resize', [],] },],
};
//# sourceMappingURL=overlay.component.js.map